import React, {useState, useCallback, useEffect} from 'react';
import ReactDOM from 'react-dom';
import { schemeYlOrRd, scaleSequential, max } from 'd3';
import { getMexico } from './getMexico';
import { Marks } from './Marks';
import { tooltipContext } from "./Tooltip";
import { useData } from './useData';

const width = 960;
const height = 500;

const App = () => {
  
  const atlasMex = getMexico();
  const wasteData = useData();

  if (!atlasMex && !wasteData) {
    return <pre>Loading...</pre>;
  }
  
  const colorValue = d => d.WasteKgs;
  const colorScale = scaleSequential(scaleSequential)
  	.domain([0, max(wasteData, colorValue)]);

  return (
    <svg width={width} height={height}>
        <Marks 
          atlasMex={atlasMex}
          wasteData={wasteData}
          colorScale={colorScale}
          colorValue={colorValue}
          />
    </svg>
  );
};


const rootElement = document.getElementById('root');
  
ReactDOM.render(<App />, rootElement);